/**
  Converts SVG file to ".poly" for FEM analysis.
  
  Output .poly coordinates are in inches, not SVG pixels.
  
  Orion Sky Lawlor, olawlor@acm.org, 2009-03-24 (Public Domain)
*/
#include <iostream>
#include <fstream>
#include <vector>
#include <math.h>
#include "svg_parse.h"
#include "svg_parse.cpp" /* for static linking */

/* FEM Interface code--everything plugs together here. */
class SVG_Dump : public svg_consumer {
public:
	SVG_Dump();
	virtual void svg_use(const char *what,const mat2 &where);
        virtual void svg_path(const std::vector<vec2> &pts,const svg_style &style);
};
const char *model_name="path.svg";
float area=0.01; /* target triangle area, in square inches */

SVG_Dump::SVG_Dump()
{
	::svg_parse(model_name,*this);
}

void SVG_Dump::svg_use(const char *what,const mat2 &where)
{
	/* ignore these */
}

void SVG_Dump::svg_path(const std::vector<vec2> &pts,const svg_style &style)
{
	/* Write out a bunch of line segments 		
	File format:
		http://www-2.cs.cmu.edu/~quake/triangle.poly.html
	*/
	std::ofstream f("image.poly");
	f<<pts.size()<<" 2 0 0\n"; /* number of vertices */
	for (unsigned int p=0;p<pts.size();p++) {
		/* negative y is because Inkscape's Y is down */
		f<<p+1<<" "<<pts[p].x*(1.0/72)-4.0<<" "<<6.0-pts[p].y*(1.0/72)<<"\n";
	}
	f<<pts.size()<<"\n"; /* number of edges */
	for (unsigned int p=0;p<pts.size();p++) {
		f<<p+1<<" "<<p+1<<" ";
		if (p+1>=pts.size()) f<<"1";
		else f<<p+2;
		f<<"\n";
	}
	f<<"0\n";
	f<<"1\n"; /* number of area constraints */
	/*          x       y        attrib?   area */
	f<<"1       0.0     0.0       0101    "<<area<<"\n";
	f.flush();
	system("triangle  -pneqVAa image.poly");
}

int main(int argc,char *argv[]) {
	if (argc>1) model_name=argv[1];
	if (argc>2) area=atof(argv[2]);
	
	SVG_Dump d;
	
	return 0;
}
