/* SVG file parser
Dr. Orion Lawlor, olawlor@acm.org, 2008-08-18 (Public Domain)
*/
#ifndef __OSL_SVG_PARSE_H
#define __OSL_SVG_PARSE_H
#include <vector>
#include "osl/vector2d.h"
#include "osl/matrix2d.h"

typedef osl::Vector2d vec2;
typedef osl::Matrix2d mat2;

/** Style for an SVG path */
class svg_style {
public:
	float width; /**< Line width, in 90dpi "pixels" */
	float opacity; /**< 1.0: opaque; 0.0: transparent */
};

/** Receives various elements from an SVG file */
class svg_consumer {
public:
	/** We've hit an instance of an SVG group, of this name, transformed like so. */
	virtual void svg_use(const char *what,const mat2 &where) =0;
	
	/** We've hit an SVG path containing these points, in pixel coordinates. */
	virtual void svg_path(const std::vector<vec2> &pts,const svg_style &style) =0;
};

/** Open and parse this SVG file.  Exits on errors. */
void svg_parse(const char *fName,svg_consumer &dest);
#endif
